@@ -56,6 +56,7 @@ from trackme_libs import (
     run_splunk_search,
     trackme_get_report,
     TrackMeRemoteConnectionError,
+    trackme_get_version,
 )
 
 # import trackme libs schema
@@ -137,14 +138,7 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         trackme_conf = {}
 
         # TrackMe version
-        trackme_version = None
-        app_confs = service.confs["app"]
-
-        for stanza in app_confs:
-            if stanza.name == "id":
-                for stanzakey, stanzavalue in stanza.content.items():
-                    if stanzakey == "version":
-                        trackme_version = stanzavalue
+        trackme_version = trackme_get_version(service)
 
         # Get schema_version_required
         schema_version_required = trackme_schema_format_version(trackme_version)
@@ -239,12 +233,6 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         trackmeconf = reqinfo_trackme["trackme_conf"]
         logger.info(f'trackmeconf="{json.dumps(trackmeconf, indent=2)}"')
 
-        # check the allow_admin_operations option
-        allow_admin_operations = int(
-            trackmeconf["trackme_general"]["allow_admin_operations"]
-        )
-        logger.info(f"allow_admin_operations={allow_admin_operations}")
-
         # init
         is_admin = False
         is_power = False
@@ -309,14 +297,7 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
             "user_level": "admin",
         }
 
-        # if allow_admin_operations is False, override is_admin
-        if is_admin and allow_admin_operations == 0:
-            # add an additional information
-            final_response["information"] = (
-                "allow_admin_operations is set to False, all admin operations are disabled currently."
-            )
-            final_response["user_level"] = "power"
-        elif is_admin and allow_admin_operations == 1:
+        if is_admin:
             final_response["user_level"] = "admin"
         elif is_power:
             final_response["user_level"] = "power"
@@ -329,10 +310,12 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         # UI defaults configuration
         ui_defaults_conf = trackmeconf.get("trackme_ui_defaults", {})
         ui_default_theme = ui_defaults_conf.get("default_theme", "dark")
+        ui_auto_refresh = ui_defaults_conf.get("auto_refresh", "1")
 
         # Add ui_default_theme to response (system-level setting)
         user_prefs_dict = {
             "ui_default_theme": ui_default_theme,
+            "ui_auto_refresh": ui_auto_refresh,
         }
 
         # add user_prefs_dict to response
@@ -408,17 +391,6 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
             missing_apps = []
             checked_apps = []
 
-            app_check = "semicircle_donut"
-            if not app_check in apps:
-                missing_apps.append(
-                    {
-                        "application_name": app_check,
-                        "splunkbase_link": "https://splunkbase.splunk.com/app/4378",
-                    }
-                )
-            else:
-                checked_apps.append(app_check)
-
             app_check = "Splunk_ML_Toolkit"
             if not app_check in apps:
                 missing_apps.append(
@@ -1223,14 +1195,7 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         logger.setLevel(loglevel)
 
         # TrackMe version
-        trackme_version = None
-        app_confs = service.confs["app"]
-
-        for stanza in app_confs:
-            if stanza.name == "id":
-                for stanzakey, stanzavalue in stanza.content.items():
-                    if stanzakey == "version":
-                        trackme_version = stanzavalue
+        trackme_version = trackme_get_version(service)
 
         # Data collection
         collection_name = "kv_trackme_virtual_tenants"
@@ -1257,11 +1222,24 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
             )
 
             # schema version: detect the current schema_version and if the upgrade is in progress
-            schema_version = int(kvrecord.get("schema_version"))
+            schema_version_raw = kvrecord.get("schema_version")
             schema_version_required = trackme_schema_format_version(trackme_version)
-            schema_version_upgrade_in_progress = False
-            if not schema_version or schema_version < schema_version_required:
+            
+            # If schema_version_required is 0 (version retrieval failed), treat as graceful degradation
+            # and don't block operations - consistent with other handlers
+            if schema_version_required == 0:
+                schema_version = int(schema_version_raw) if schema_version_raw is not None else None
+                schema_version_upgrade_in_progress = False
+            elif schema_version_raw is None:
+                # If schema_version is missing (e.g., tenant was created when version retrieval failed),
+                # treat it as needing an upgrade
+                schema_version = None
                 schema_version_upgrade_in_progress = True
+            else:
+                schema_version = int(schema_version_raw)
+                schema_version_upgrade_in_progress = False
+                if not schema_version or schema_version < schema_version_required:
+                    schema_version_upgrade_in_progress = True
 
             # retrieve the components configuration
             try:
